# Kodexa

![Build and Publish](https://github.com/kodexa-ai/kodexa/workflows/Build%20and%20Publish/badge.svg)
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fkodexa-ai%2Fkodexa.svg?type=shield)](https://app.fossa.io/projects/git%2Bgithub.com%2Fkodexa-ai%2Fkodexa?ref=badge_shield)

![https://docs.readthedocs.io/en/latest/?badge=latest](https://readthedocs.org/projects/docs/badge/?version=latest) 

The Kodexa Content Framework framework is designed to allow you to work with a wide range of unstructured and semi-structured content and enables you to work with the Kodexa Cloud (https://cloud.kodexa.com).

## Documentation & Examples

Documentation is available at [ReadTheDocs](https://kodexa-kodexa.readthedocs-hosted.com/en/latest/)

For more information on how to use Kodexa see https://developer.kodexa.com/developers/clients/python

## Set-up

Ensure you have Anaconda 3 or greater installed, then run:

    conda env create -f environment.yml --force
    
Activate the conda environment with the command:

    conda activate kodexa
    

    


## License
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fkodexa-ai%2Fkodexa.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fkodexa-ai%2Fkodexa?ref=badge_large)